@@ -289,9 +289,9 @@ ewmh_update_lists(Wm *w)
 	  if (current_cycle->xid != None)
 	    {
 	      char str_tmp[256] = "";
-	      sprintf(str_tmp, "%s=%li|", 
-		      current_cycle->bin_name, 
-		      current_cycle->xid);
+	      snprintf(str_tmp, 256, "%s=%li|", 
+		       current_cycle->bin_name, 
+		       current_cycle->xid);
 	      
 	      strcat(bin_map_str, str_tmp);
 	      
@@ -382,8 +382,6 @@ ewmh_update_rects(Wm *w)
   val[3] = w->dpy_height - wm_get_offsets_size(w, NORTH, NULL, True)
     - wm_get_offsets_size(w, SOUTH, NULL, True);
 
-  dbg("%s(): val[3] is %li\n", __func__, val[3] );
-
   if (w->flags & DESKTOP_DECOR_FLAG)
     {
       /* Desktop is decorated, needs to know frame border sizes  */
@@ -395,13 +393,15 @@ ewmh_update_rects(Wm *w)
       val[3] -= theme_frame_defined_height_get(w->mbtheme, FRAME_MAIN); 
     }
 
-  dbg("%s(): val[3] now is %li\n", __func__, val[3] );
+  dbg("%s(): vals now is %li, %li, %li, %li ( root: %li )\n", 
+      __func__, val[0], val[1], val[2], val[3], w->root );
 
   XChangeProperty(w->dpy, w->root, w->atoms[_NET_WORKAREA],
 		  XA_CARDINAL, 32, PropModeReplace, (unsigned char *)val, 4);
   
   XChangeProperty(w->dpy, w->root, w->atoms[_NET_DESKTOP_GEOMETRY],
 		  XA_CARDINAL, 32, PropModeReplace, (unsigned char *)val, 4);
+
 }
 
 void 
@@ -621,13 +621,17 @@ ewmh_get_utf8_prop(Wm *w, Window win, Atom req_atom)
   long           bytes_after, n_items;
   unsigned char *str = NULL;
 
+  misc_trap_xerrors();
+
   result =  XGetWindowProperty (w->dpy, win, req_atom,
 				0, 1024L,
 				False, w->atoms[UTF8_STRING],
 				&type, &format, &n_items,
 				&bytes_after, (unsigned char **)&str);
 
-  if (result != Success || str == NULL)
+
+
+  if (misc_untrap_xerrors() || result != Success || str == NULL)
     {
       if (str) XFree (str);
       return NULL;
@@ -660,13 +664,15 @@ ewmh_get_icon_prop_data(Wm *w, Window win)
   long           bytes_after, n_items;
   unsigned char *data = NULL;
 
+  misc_trap_xerrors();
+
   result =  XGetWindowProperty (w->dpy, win, w->atoms[_NET_WM_ICON],
 				0, 100000L,
 				False, XA_CARDINAL,
 				&type, &format, &n_items,
 				&bytes_after, (unsigned char **)&data);
 
-  if (result != Success || data == NULL)
+  if (misc_untrap_xerrors() || result != Success || data == NULL)
     {
       if (data) XFree (data);
       return NULL;
